==> 0.4.72.tar.gz: lib/widgets/filter_widget/component/seached_list.dart <==
// ignore_for_file: must_be_immutable

library seached_list;

import 'dart:async';

import 'package:flutter/material.dart';
import 'package:wowit/controllers/load_more_base_controller.dart';
import 'package:wowit/controllers/searched_controller.dart';
import 'package:wowit/widgets/filter_widget/filter_widget.dart';
import 'package:wowit/widgets/filter_widget/util.dart';
part 'package:wowit/controllers/search_controller.dart';

class SearchedList extends FilterWidget<_SearchController> {
  SearchedList({
    super.key,
    required this.searchedListModel,
    required super.fieldNameSearching,
    this.searchedDataLoader,
    this.scrollController,
  }) : super(
          _SearchController(searchedDataLoader),
          isFilterOnServer: searchedListModel.isFilterOnServer,
          title: searchedListModel.title,
          filterItems: searchedListModel.filterItems,
        );

  final SearchedListModel searchedListModel;
  final SearchedDataLoader? searchedDataLoader;

  ScrollController? scrollController;
  Timer? timer;

  @override
  Widget getConditionView(
    Map<String, Object?> mapCondition,
    void Function(String fieldName, Object value) onValueChange,
  ) {
    return searchedListModel.getConditionView(mapCondition, onValueChange);
  }

  @override
  void loadMore() {
    getController().loadMore();
  }

  @override
  Widget getMainView(
    BuildContext context,
    Map<String, List<Map<String, Object?>?>?> data,
    _SearchController controller,
  ) {
    return controller.dataList.isNotEmpty
        ? Padding(
            padding: searchedListPadding ?? const EdgeInsets.all(0.0),
            child: ListView.builder(
              controller: scrollController,
              keyboardDismissBehavior: ScrollViewKeyboardDismissBehavior.onDrag,
              itemCount: controller.dataList.length + 1,
              itemBuilder: (BuildContext context, index) {
                if (index < controller.dataList.length &&
                    controller.dataList[index] != null) {
                  return searchedListModel
                      .getLineView(controller.dataList[index]!);
                }
                if (controller.isLoadMoreRunning == true) {
                  return getLoadingView();
                }
                if (controller.hasNextPage == false && index > 20) {
                  return getEndOfPageView();
                }
                return const SizedBox();
              },
            ),
          )
        : getEmptyView(controller);
  }

  void search(String keyword) {
    timer?.cancel();
    timer = Timer(const Duration(milliseconds: 500), () {
      onConditionValueChanged(fieldNameSearching, keyword);
      searchedListModel.isFilterOnServer
          ? applyFilterOnServer()
          : applyFilterBaseOnList();
      timer?.cancel();
    });
  }
}

class SearchedListModel {
  SearchedListModel({
    required this.title,
    required this.filterItems,
    required this.getLineView,
    required this.getConditionView,
    required this.searchedListPadding,
    required this.isFilterOnServer,
  });

  final String title;
  final List<FilterItem> filterItems;
  final GetLineView getLineView;
  final GetConditionView getConditionView;
  final EdgeInsets searchedListPadding;
  final bool isFilterOnServer;
}

==> 0.5.6.tar.gz: lib/widgets/filter_widget/component/seached_list.dart <==
// ignore_for_file: must_be_immutable

library seached_list;

import 'dart:async';

import 'package:flutter/material.dart';
import 'package:wowit/controllers/load_more_base_controller.dart';
import 'package:wowit/controllers/searched_controller.dart';
import 'package:wowit/widgets/filter_widget/filter_widget.dart';
import 'package:wowit/widgets/filter_widget/util.dart';
part 'package:wowit/controllers/search_controller.dart';

class SearchedList extends FilterWidget<SearchController> {
  SearchedList({
    super.key,
    required this.searchedListModel,
    required super.fieldNameSearching,
    this.searchedDataLoader,
    this.scrollController,
  }) : super(
          SearchController(searchedDataLoader),
          isFilterOnServer: searchedListModel.isFilterOnServer,
          title: searchedListModel.title,
          filterItems: searchedListModel.filterItems,
        );

  final SearchedListModel searchedListModel;
  final SearchedDataLoader? searchedDataLoader;

  ScrollController? scrollController;
  Timer? timer;

  @override
  Widget getConditionView(
    Map<String, Object?> mapCondition,
    void Function(String fieldName, Object value) onValueChange,
  ) {
    return searchedListModel.getConditionView(mapCondition, onValueChange);
  }

  @override
  void loadMore() {
    getController().loadMore();
  }

  @override
  Widget getMainView(
    BuildContext context,
    Map<String, List<Map<String, Object?>?>?> data,
    SearchController controller,
  ) {
    return controller.dataList.isNotEmpty
        ? Padding(
            padding: searchedListPadding ?? const EdgeInsets.all(0.0),
            child: ListView.builder(
              controller: scrollController,
              keyboardDismissBehavior: ScrollViewKeyboardDismissBehavior.onDrag,
              itemCount: controller.dataList.length + 1,
              itemBuilder: (BuildContext context, index) {
                if (index < controller.dataList.length &&
                    controller.dataList[index] != null) {
                  return searchedListModel
                      .getLineView(controller.dataList[index]!);
                }
                if (controller.isLoadMoreRunning == true) {
                  return getLoadingView();
                }
                if (controller.hasNextPage == false && index > 20) {
                  return getEndOfPageView();
                }
                return const SizedBox();
              },
            ),
          )
        : getEmptyView(controller);
  }

  void search(String keyword) {
    timer?.cancel();
    timer = Timer(const Duration(milliseconds: 500), () {
      onConditionValueChanged(fieldNameSearching, keyword);
      searchedListModel.isFilterOnServer
          ? applyFilterOnServer()
          : applyFilterBaseOnList();
      timer?.cancel();
    });
  }
}

class SearchedListModel {
  SearchedListModel({
    required this.title,
    required this.filterItems,
    required this.getLineView,
    required this.getConditionView,
    required this.searchedListPadding,
    required this.isFilterOnServer,
  });

  final String title;
  final List<FilterItem> filterItems;
  final GetLineView getLineView;
  final GetConditionView getConditionView;
  final EdgeInsets searchedListPadding;
  final bool isFilterOnServer;
}
